/**
 * Console provides a simple main(). This is a non-GUI version of XM.
 *
 * @author <a href="http://www.marchal.com">Beno&#238;t Marchal</a>
 */

// Copyright 2001, Benot Marchal.

package org.ananas.xm;

import java.io.File;
import org.xml.sax.SAXParseException;

public class Console
{
   /**
    * Entry point for a Console (not GUI) version of XM.
    * It expects two parameters: source and target directories.
    * @param params command-line parameters
    */
   public final static void main(String[] params)
   {
      try
      {
         boolean build = false,
                 rules = false;
         String rulesDir = "rules",
                sourceDir = null,
                targetDir = null;
         for(int i = 0;i < params.length;i++)
         {
            if(rules)
            {
               rulesDir = params[i];
               rules = false;
            }
            else if(params[i].equals("-build"))
               build = true;
            else if(params[i].equals("-rules"))
               rules = true;
            else if(sourceDir == null)
               sourceDir = params[i];
            else if(targetDir == null)
               targetDir = params[i];
         }
         Messenger messenger = new DefaultMessenger();
         DirectoryWalker walker =
            new DirectoryWalker(messenger,rulesDir,build);
         walker.walk(sourceDir,targetDir);
      }
      catch(XMException e)
      {
         Exception x = e.getException();
         if(x != null && x instanceof SAXParseException)
         {
            SAXParseException spe = (SAXParseException)x;
            System.err.print("Parsing error: ");
            System.err.print(spe.getMessage());
            System.err.print(" in ");
            System.err.print(spe.getSystemId());
            System.err.print(" at ");
            System.err.print(spe.getLineNumber());
            System.err.print(", ");
            System.err.println(spe.getColumnNumber());
         }
         else
         {
            e.printStackTrace();
            System.err.println(e.getMessage());
         }
      }
      catch(Exception e)
      {
         e.printStackTrace();
         System.err.println(e.getMessage());
      }
   }
}
