/**
 * Simply copy the file from the source to the target directory.
 *
 * @author <a href="http://www.marchal.com">Beno&#238;t Marchal</a>
 */

// Copyright 2001, Benot Marchal.

package org.ananas.xm;

import java.io.*;

public class CopyingMover
   extends DefaultMoverImpl
{
   /**
    * buffer, for obvious reasons access to this buffer must
    * be synchronized
    */
   protected byte[] bytes = new byte[1024];

   /**
    * Return the name the file would have after moving. In this case,
    * it's left unchanged.
    * @param file file the mover would have to move
    * @return the extension it would give the file in the target directory
    */
   public String getTargetName(File file)
   {
      return file.getName();
   }

   /**
    * Creates a CopyingMover.
    * @param messenger reports error on this Messenger
    * @param build process all files irrespective of last modified
    */
   public CopyingMover(Messenger messenger,boolean build)
   {
      super(messenger,build);
   }

   /**
    * Move one file.
    * @param sourceFile the file to move
    * @param targetDir the directory to copy the result to
    * @param depth how far from the root (0 = root)
    * @return styled file or null if the file was ignored
    */
   public File move(File sourceFile,File targetDir,int depth)
      throws XMException
   {
      try
      {
         File targetFile = new File(targetDir,getTargetName(sourceFile));
         if(!build && targetFile.exists())
            if(targetFile.lastModified() >= sourceFile.lastModified())
               return null;
         synchronized(bytes)
         {
            FileInputStream in = new FileInputStream(sourceFile);
            FileOutputStream out = new FileOutputStream(targetFile);
            for(int len = in.read(bytes);len != -1;len = in.read(bytes))
               out.write(bytes,0,len);
         }
         return targetFile;
      }
      catch(IOException e)
      {
         messenger.error(new XMException(e));
      }
      return null;
   }
}
