/**
 * Provides default implementation and helpful methods for the movers.
 *
 * @author <a href="http://www.marchal.com">Beno&#238;t Marchal</a>
 */

// Copyright 2001, Benot Marchal.

package org.ananas.xm;

import java.io.*;
import org.xml.sax.*;
import javax.xml.transform.*;
import javax.xml.transform.sax.*;
import javax.xml.transform.stream.*;
import org.apache.xalan.serialize.*;

abstract public class DefaultMoverImpl
   implements Mover
{
   /**
    * messenger to report errors to
    */
   protected Messenger messenger;

   /**
    * whether to "build" the project, i.e. process all the files
    */
   protected boolean build;

   /**
    * Creates a StylingMover from an XSLT stylesheet file.
    * @param messenger Messenger to report errors to
    * @param build perform a build, i.e. process all the files
    *    irrespective of when they were last modified
    */
   public DefaultMoverImpl(Messenger messenger,boolean build)
   {
      this.messenger = messenger;
      this.build = build;
   }

   /**
    * compute a file extension
    * @param file file to compute the extension from
    * @return the file extension (excluding the .), "" if none
    */
   public static String getExtension(File file)
   {
      String filename = file.getName();
      int index = filename.lastIndexOf('.');
      return index != -1 ? filename.substring(index + 1) : "";
   }

   /**
    * compute the filename without the extension
    * @param file file to compute the extension from
    * @return the file name without the extension (excluding the .)
    */
   public static String getDisplayName(File file)
   {
      String filename = file.getName();
      int index = filename.lastIndexOf('.');
      return index != -1 ? filename.substring(0,index) : filename;
   }
}
