/**
 * Handles moving the files, recognizes many file types, helped
 * by the other movers.
 *
 * @author <a href="http://www.marchal.com">Beno&#238;t Marchal</a>
 */

package org.ananas.xm;

import java.io.*;
import java.util.*;
import org.xml.sax.*;
import org.ananas.util.*;

public class MoversSupervisor
{
   /**
    * different movers, indexed by their suffixes
    */
   protected Map movers;

   /**
    * copying mover, acts as a default
    */
   protected Mover copier;

   /**
    * Creates a default supervisor.
    * @param messenger Messenger to report errors to
    * @parma templates templates to use for styling
    * @param build perform a build, i.e. process all the files
    */
   public MoversSupervisor(Messenger messenger,
                           TemplatesManager templates,
                           boolean build)
      throws XMException
   {
      try
      {
         movers = new HashMap();
         // eventually, there will be more options here
         movers.put("xml",new StylingMover(messenger,this,templates,build));
         XMLReader xmlReaderWithDTD = JAXPHelper.createXMLReader(true,true),
                   xmlReaderWithoutDTD = JAXPHelper.createXMLReader(true,false);
         XMLFilter filterWithDTD = new WalkFilter(xmlReaderWithDTD,messenger),
                   filterWithoutDTD = new WalkFilter(xmlReaderWithoutDTD,messenger);
         movers.put("xm",new StylingMover(messenger,this,templates,filterWithDTD,filterWithoutDTD,build));
         copier = new CopyingMover(messenger,build);
         // for the AWT (awt.be), they don't want to process .edoc files
         // should move this into a config file or command-line switch
         movers.put("edoc",new NoneMover(messenger,build));
      }
      catch(SAXException e)
      {
         throw new XMException(e);
      }
   }

   /**
    * returns the Mover to use on this file.
    * @param file file to move
    * @return the mover to use for this file
    */
   public Mover getMover(File file)
   {
      Mover mover = (Mover)movers.get(DefaultMoverImpl.getExtension(file));
      return mover == null ? copier : mover;
   }
}
